@@ -1,7 +1,11 @@
 $(function() {
     var close = 'img';
-    var expose = {color: '#333', loadSpeed: 200, opacity: 0.9};
-    var overlay = {expose: expose, close: close};
+    var expose = {color: '#333', loadSpeed: 0, closeSpeed: 0, opacity: 0.9};
+    var overlay = {
+        expose: expose,
+        close: close,
+        onLoad: function() {$('.image-overlay').expose(expose);}
+    }
     $('.gallery a[rel]').overlay(overlay).click(function() {
         location = $(this).attr('rel') + '-show';
     });
